Summarizes topics in a model. Called by tidylda
and refit.tidylda and used to augment
print.tidylda.
summarize_topics(theta, beta, dtm)Returns a tibble with the following columns:
topic is the integer row number of beta.
prevalence is the frequency of each topic throughout the corpus it
was trained on normalized so that it sums to 100.
coherence makes a call to calc_prob_coherence
using the default 5 most-probable terms in each topic.
top_terms displays the top 5 most-probable terms in each topic.
numeric matrix whose rows represent P(topic|document)
numeric matrix whose rows represent P(token|topic)
a document term matrix or term co-occurrence matrix of class dgCMatrix.